Learn R Programming

ihpdr (version 1.2.1)

ihpd_get: Download Data from the International House Price Database

Description

Available downloads:

  1. raw: Raw Data

  2. gsadf: Generalized sup ADF statistics

  3. bsadf: Backward sup ADF statistic sequence

Usage

ihpd_get(symbol = c("raw", "gsadf", "bsadf"), version = NULL, verbose = TRUE)

Arguments

symbol

Which dataset to download.

version

Which version to download. Version number should be a character of the following format %Y%q (e.g. '1801' - corresponds to year 2018, Quarter 1). Versions start from '1102'. Defaults at the latest available.

verbose

whether to print the url of the excel file that is accessing.

Value

Returns a tibble in long format.

Details

raw

Includes the following time series for the countries covered:

  • hpi: The house price index.

  • rhpi: The house price index expressed in real terms.

  • pdi: The personal disposable income index.

  • rpdi: The personal disposable income expressed in real terms index.

All variables in real terms are deflated with the personal consumption expenditure (PCE) deflator.

The exuberance indicators include

gsadf

  • type: real house price index (rhpi) and the ratio of rhpi to real personal disposable income (rpdi)

  • lag: lag length of 1 and 4

  • sig: significance level for the critical value

  • value: test statistics for explosive behavior

  • crit: 95 percent critical values.

bsadf

The exuberance indicators include

  • type: real house price index (rhpi) and the ratio of rhpi to real personal disposable income (rpdi)

  • lag: lag length of 1 and 4,

  • value: test statistics for explosive behavior

  • crit: 95 percent critical values.

Examples

Run this code
# NOT RUN {
ihpd_get()
# }

Run the code above in your browser using DataLab